@@ -6,10 +6,14 @@ function(cop=NULL, v, t, para=NULL, ...) {
             #print(LHS - dc)
             return(LHS - dc)
     }
-    try(rt <- uniroot(func,interval=c(0,1),
-                      v=v, LHS=t, cop=cop, para=para, ...))
-    if(length(rt$root) != 0) {
-      u <- rt$root
+
+    my.rt <- NULL
+    try(my.rt <- uniroot(func,interval=c(0,1),
+                          v=v, LHS=t, cop=cop, para=para, ...))
+
+    if(is.null(my.rt)) return(NA)
+    if(length(my.rt$root) != 0) {
+      u <- my.rt$root
       return(u)
     }
     else {
